@@ -1,5 +1,5 @@
 from itertools import permutations
-from typing import Collection, Iterable, List, Set, Tuple, Type
+from typing import ClassVar, Collection, Dict, Iterable, List, Set, Tuple, Type, Union
 
 from .base import BaseType, ImportPathList
 
@@ -9,6 +9,11 @@ class StringSerializable(BaseType):
     Mixin for classes which are used to (de-)serialize some values in a string form
     """
 
+    class TypeStyle:
+        use_actual_type = 'use_actual_type'
+
+    actual_type: ClassVar[Type]
+
     @classmethod
     def to_internal_value(cls, value: str) -> 'StringSerializable':
         """
@@ -29,12 +34,17 @@ class StringSerializable(BaseType):
         raise NotImplementedError()
 
     @classmethod
-    def to_typing_code(cls) -> Tuple[ImportPathList, str]:
+    def to_typing_code(cls, types_style: Dict[Union['BaseType', Type['BaseType']], dict]) -> Tuple[ImportPathList, str]:
         """
         Unlike other BaseType's subclasses it's a class method because StringSerializable instance is not parameterized
         as a metadata instance but contains actual data
         """
         cls_name = cls.__name__
+        options = cls.get_options_for_type(cls, types_style)
+        if options.get(cls.TypeStyle.use_actual_type):
+            if cls.actual_type.__module__ != 'builtins':
+                return [(cls.actual_type.__module__, cls.actual_type.__name__)], cls.actual_type.__name__
+            return [], cls.actual_type.__name__
         return [('json_to_models.dynamic_typing', cls_name)], cls_name
 
     def __iter__(self):
@@ -117,6 +127,8 @@ registry = StringSerializableRegistry()
 
 @registry.add()
 class IntString(StringSerializable, int):
+    actual_type = int
+
     @classmethod
     def to_internal_value(cls, value: str) -> 'IntString':
         return cls(value)
@@ -127,6 +139,8 @@ class IntString(StringSerializable, int):
 
 @registry.add(replace_types=(IntString,))
 class FloatString(StringSerializable, float):
+    actual_type = float
+
     @classmethod
     def to_internal_value(cls, value: str) -> 'FloatString':
         return cls(value)
@@ -138,6 +152,7 @@ class FloatString(StringSerializable, float):
 @registry.add()
 class BooleanString(StringSerializable, int):
     # We can't extend bool class, but we can extend int with same result excepting isinstance and issubclass check
+    actual_type = bool
 
     @classmethod
     def to_internal_value(cls, value: str) -> 'BooleanString':
